#undef PACKAGE
#undef VERSION

#undef GNOME_LIBS_VERSION
#undef HAVE_GNOME_PRINT
#undef HAVE_LIBSM
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS

/* gmime uses these */
#undef HAVE_TIMEZONE
#undef HAVE_TM_GMTOFF

#undef  GNOME_ICONDIR
